/*
 * Copyright (c) 1989 by Apollo Computer, Inc.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted,
 * provided that the above copyright notice appear in all copies and that
 * both that copyright notice and this permission notice appear in
 * supporting documentation.
 *
 * This file is provided AS IS with no warranties of any kind.  The authors
 * shall have no liability with respect to the infringement of copyrights,
 * trade secrets or any patents by this file or any part thereof.  In no
 * event will the authors be liable for any lost revenue or profits or
 * other special, indirect and consequential damages.
 *
 * Copyright (c) 1989 Carnegie-Mellon University
 * Copyright (c) 1988 Carnegie-Mellon University
 * Copyright (c) 1987 Carnegie-Mellon University
 * All rights reserved.  The CMU software License Agreement specifies
 * the terms and conditions for use and redistribution.
 *
 *
 * Bug reports/fixes, comments and enhancements should be sent to:
 *       nawaf@osf.org
 *       Nawaf Bitar
 *       Open Software Foundation
 *       11 Cambridge Center
 *       Cambridge, MA 02142
 *
 * Contributors:  Nawaf Bitar
 *		  Tom Lemaire
 *		  Vidas Neverauskas
 *		  Ed Sharpe
 *                Bryan Ford
 *
 */
#ifndef _amiga_vm_param_
#define _amiga_vm_param_

#include <motorola/m68k/vm_param.h>


/* Note: These ranges are temporarily hacked to get the kernel and SIM in positive addresses.  */

#ifdef ASSEMBLER

#define VM_MIN_ADDRESS	        (0x10000000)
#define VM_MAX_ADDRESS          (0x40000000)

#define VM_MIN_KERNEL_ADDRESS   (0x40000000)
#define VM_MAX_KERNEL_ADDRESS   (0x7fffffff)

#else !ASSEMBLER

#define VM_MIN_ADDRESS	        ((vm_offset_t) 0x10000000)      /* User-mode address space */
#define VM_MAX_ADDRESS          ((vm_offset_t) 0x40000000)

#define VM_MIN_KERNEL_ADDRESS   ((vm_offset_t) 0x40000000)      /* Kernel address space */
#define VM_MAX_KERNEL_ADDRESS   ((vm_offset_t) 0x7f000000)


/* Chip memory is directly mapped into the kernel address space at a high address.
   If we're careful to make sure the all the bits the hardware might see (say the
   low 24 bits) are zero, then these addresses can be plugged into hardware DMA
   registers without translation.  This method can also apply to user-space
   servers that directly access chip memory and the custom chips (although in
   that case chip memory would be mapped at a lower address).  */
#define VM_MIN_CHIP_ADDRESS     ((vm_offset_t) 0x7f000000)
#define VM_MAX_CHIP_ADDRESS     ((vm_offset_t) 0x7fff0000)


/* Standard Amiga hardware register addresses, as mapped into kernel memory.  */
/* (physical addresses are defined in the headers for the respective hardware.) */
#define VM_HARDWARE_ADDRESS     ((vm_offset_t) 0x7fff0000)

#define VM_CUSTOM       (VM_HARDWARE_ADDRESS+PAGE_SIZE*0+(PHYS_CUSTOM & (PAGE_MASK)))
#define VM_CIAA         (VM_HARDWARE_ADDRESS+PAGE_SIZE*1+(PHYS_CIAA & (PAGE_MASK)))
#define VM_CIAB         (VM_HARDWARE_ADDRESS+PAGE_SIZE*2+(PHYS_CIAB & (PAGE_MASK)))
#define VM_A3000_DMAC	(VM_HARDWARE_ADDRESS+PAGE_SIZE*3+(PHYS_A3000_DMAC & (PAGE_MASK)))
#define VM_A2091_DMAC	(VM_HARDWARE_ADDRESS+PAGE_SIZE*3+(PHYS_A2091_DMAC & (PAGE_MASK)))
#define VM_GVP11_DMAC	(VM_HARDWARE_ADDRESS+PAGE_SIZE*4+(PHYS_GVP11_DMAC & (PAGE_MASK)))

#endif !ASSEMBLER


#define KERNEL_BASE		VM_MIN_KERNEL_ADDRESS	/* where user stack grows down, and kernel starts */
#define KERNEL_STACK_SIZE       8192
#define INTSTACK_SIZE           8192


#endif _amiga_vm_param_
